## $Id: interfaces.py 17436 2023-06-18 20:11:00Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('kofacustom.iuokada')

class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    clearance_fee = schema.Float(
        title = _(u'Acceptance Fee'),
        default = 0.0,
        required = False,
        )

    booking_fee = schema.Float(
        title = _(u'Bed Booking Fee'),
        default = 0.0,
        required = False,
        )

    maint_fee = schema.Float(
        title = _(u'Rent (fallback)'),
        default = 0.0,
        required = False,
        )

    late_registration_fee = schema.Float(
        title = _(u'Late Course Reg. Fee'),
        default = 0.0,
        required = False,
        )

    transcript_local_fee = schema.Float(
        title = _(u'Transcript Fee Local Students'),
        default = 0.0,
        required = False,
        )

    transcript_overseas_fee = schema.Float(
        title = _(u'Transcript Fee Oversea Students'),
        default = 0.0,
        required = False,
        )

    transfer_fee = schema.Float(
        title = _(u'Transfer Fee'),
        default = 0.0,
        required = False,
        )

    interswitch_enabled = schema.Bool(
        title = _(u'Interswitch Collegepay integration enabled'),
        default = True,
        )

    interswitch_paydirect_enabled = schema.Bool(
        title = _(u'Interswitch Paydirect integration enabled'),
        default = True,
        )

    etranzact_webconnect_enabled = schema.Bool(
        title = _(u'Etranzact Webconnect integration enabled'),
        default = False,
        )

    etranzact_payoutlet_enabled = schema.Bool(
        title = _(u'Etranzact Payoutlet integration enabled'),
        default = False,
        )

    # Additional fees in custom package add here

    grad_clearance_fee = schema.Float(
        title = _(u'Clearance Fee'),
        default = 0.0,
        required = False,
        )

    registration_fee = schema.Float(
        title = _(u'Registration Fee'),
        default = 0.0,
        required = False,
        )

    late_registration_fee = schema.Float(
        title = _(u'Late Registration Fee'),
        default = 0.0,
        required = False,
        )

    science_fee = schema.Float(
        title = _(u'Science Bench Fee'),
        default = 0.0,
        required = False,
        )

    clinical_fee = schema.Float(
        title = _(u'Clinical Fee (Medical Students)'),
        default = 0.0,
        required = False,
        )

    develop_fee = schema.Float(
        title = _(u'Development Fee'),
        default = 0.0,
        required = False,
        )

    municipal_fresh_fee = schema.Float(
        title = _(u'Municipal Fee Fresh Students'),
        default = 0.0,
        required = False,
        )

    municipal_returning_fee = schema.Float(
        title = _(u'Municipal Fee Returning Students'),
        default = 0.0,
        required = False,
        )

    alumni_fee = schema.Float(
        title = _(u'Alumni Fee'),
        default = 0.0,
        required = False,
        )

    conv_fee = schema.Float(
        title = _(u'Convocation Fee'),
        default = 0.0,
        required = False,
        )

    matric_fee = schema.Float(
        title = _(u'Matriculation Fee'),
        default = 0.0,
        required = False,
        )

    waecneco_fee = schema.Float(
        title = _(u'WAEC & NECO Verification Fee'),
        default = 0.0,
        required = False,
        )

    jambver_fee = schema.Float(
        title = _(u'JAMB Verification Fee'),
        default = 0.0,
        required = False,
        )

    book_fee = schema.Float(
        title = _(u'Book Deposit'),
        default = 0.0,
        required = False,
        )

    parentsconsult_fee = schema.Float(
        title = _(u'Parents Consultative Forum (PCF) Fee'),
        default = 0.0,
        required = False,
        )

    pharmlab_fee = schema.Float(
        title = _(u'Pharmacy Lab Support Fee'),
        default = 0.0,
        required = False,
        )

    lo_ident_fee = schema.Float(
        title = _(u'Letter of Identification Fee'),
        default = 0.0,
        required = False,
        )

    change_course_fee = schema.Float(
        title = _(u'Change of Course Fee'),
        default = 0.0,
        required = False,
        )

    #make_up_fee = schema.Float(
    #    title = _(u'Make-up Fee'),
    #    default = 0.0,
    #    required = False,
    #    )

    iuits_fee = schema.Float(
        title = _(u'IUITS Fee'),
        default = 0.0,
        required = False,
        )

    fine_fee = schema.Float(
        title = _(u'Fine'),
        default = 0.0,
        required = False,
        )

    resit_fee = schema.Float(
        title = _(u'Make-Up Examination Course Fee'),
        default = 0.0,
        required = False,
        )

    makeup_admin_fee = schema.Float(
        title = _(u'Make-Up Registration Fee'),
        default = 0.0,
        required = False,
        )

    id_card_fee = schema.Float(
        title = _(u'Student ID Card Fee'),
        default = 0.0,
        required = True,
        )
    pg_other_fee = schema.Float(
        title = _(u'PG Other Charges'),
        default = 0.0,
        required = True,
        )

    application_fee = schema.Float(
        title = _(u'Application Fee'),
        default = 0.0,
        required = False,
        )
    jupeb_form_fee = schema.Float(
        title = _(u'JUPEB Form Fee'),
        default = 0.0,
        required = False,
        )

    jupeb_acc_fee = schema.Float(
        title = _(u'JUPEB Acceptance Fee'),
        default = 0.0,
        required = False,
        )

    jupeb_sci_fee = schema.Float(
        title = _(u'JUPEB Science Fee'),
        default = 0.0,
        required = False,
        )

    jupeb_arts_fee = schema.Float(
        title = _(u'JUPEB Arts Fee'),
        default = 0.0,
        required = False,
        )

    jupeb_hostel_fee = schema.Float(
        title = _(u'JUPEB Hostel Fee'),
        default = 0.0,
        required = False,
        )

    jupeb_reg_fee = schema.Float(
        title = _(u'JUPEB Administrative Fee'),
        default = 0.0,
        required = False,
        )

    pg_application_fee = schema.Float(
        title = _(u'PG Application Fee'),
        default = 0.0,
        required = False,
        )

    health_insurance_fee = schema.Float(
        title = _(u'Student Health Insurance Fee'),
        default = 0.0,
        required = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order